CREATE TABLE table_company (
  company_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  company_name TEXT NULL,
  PRIMARY KEY(company_id)
)
ENGINE=InnoDB;

CREATE TABLE table_filter (
  filter_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  filter_description TEXT NULL,
  filter_content LONGTEXT NULL,
  PRIMARY KEY(filter_id)
)
ENGINE=InnoDB;

CREATE TABLE table_version (
  version_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  version_number INTEGER UNSIGNED NULL,
  PRIMARY KEY(version_id)
)
ENGINE=InnoDB;

CREATE TABLE table_category (
  category_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  category_name Varchar(60) NOT NULL,
  category_envDesc TEXT NOT NULL,
  category_jarName TEXT NULL,
  PRIMARY KEY(category_id)
)
ENGINE=InnoDB;

CREATE TABLE table_category_stat (
  category_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  date DATETIME NULL,
  nb_tests INTEGER UNSIGNED NULL,
  nb_tests_implemented INTEGER UNSIGNED NULL,
  nb_testcases INTEGER UNSIGNED NULL,
  nb_testcases_implemented INTEGER UNSIGNED NULL,
  FOREIGN KEY(category_id)
    REFERENCES table_category(category_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;




CREATE TABLE table_attr_string (
  attr_string_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attr_string_name Varchar(60) NOT NULL,
  attr_string_mandatory BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attr_string_id)
)
ENGINE=InnoDB;

CREATE TABLE table_attr_integer (
  attr_integer_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attr_integer_name Varchar(60) NOT NULL,
  attr_integer_mandatory BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attr_integer_id)
)
ENGINE=InnoDB;

CREATE TABLE table_attr_boolean (
  attr_boolean_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attr_boolean_name Varchar(60) NOT NULL,
  attr_boolean_mandatory BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attr_boolean_id)
)
ENGINE=InnoDB;

CREATE TABLE table_folder (
  folder_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id_2 INTEGER UNSIGNED NULL,
  folder_name TEXT NULL,
  category_id INTEGER UNSIGNED NOT NULL,
  company_id INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(folder_id),
  INDEX folder_FKIndex1(folder_id_2),
  INDEX folder_FKIndex2(category_id),
  INDEX folder_FKIndex3(company_id),
  FOREIGN KEY(folder_id_2)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(category_id)
    REFERENCES table_category(category_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(company_id)
    REFERENCES table_company(company_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_sut (
  sut_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  sut_name TEXT NULL,
  sut_version TEXT NULL,
  folder_id INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(sut_id),
  INDEX sut_FKIndex1(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_agent (
  agent_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  agent_name TEXT NOT NULL,
  agent_os TEXT NOT NULL,
  agent_description TEXT NULL,
  folder_id INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(agent_id),
  INDEX agent_FKIndex1(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_user (
  user_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  user_name TEXT NULL,
  folder_id INTEGER UNSIGNED NOT NULL,
  user_password TEXT NULL,
  user_local Varchar(5) DEFAULT 'en_US' NOT NULL,
  user_rights TEXT NULL,
  user_email Varchar(50) DEFAULT '' NOT NULL,
  user_enabled BOOL NOT NULL DEFAULT 1,
  PRIMARY KEY(user_id),
  INDEX user_FKIndex1(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_defect_generic (
  defect_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  external_id INTEGER UNSIGNED NULL,
  PRIMARY KEY(defect_id),
  INDEX defect_FKIndex1(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_defect_integrated (
  defect_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  defect_name TEXT NULL,
  defect_description TEXT NULL,
  priority INTEGER NULL,
  severity INTEGER NULL,
  reporter INTEGER UNSIGNED NOT NULL,
  assigned_to INTEGER UNSIGNED NOT NULL,
  status TEXT NULL,
  PRIMARY KEY(defect_id),
  INDEX defect_FKIndex1(folder_id),
  INDEX defect_FKIndex2(reporter),
  INDEX defect_FKIndex3(assigned_to),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(reporter)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(assigned_to)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_requirement (
  requirement_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  requirement_type TEXT NULL,
  requirement_name TEXT NOT NULL,
  requirement_description TEXT NULL,
  PRIMARY KEY(requirement_id),
  INDEX table_requirement_FKIndex2(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_campaign (
  campaign_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  campaign_name TEXT NULL,
  PRIMARY KEY(campaign_id),
  INDEX campaign_FKIndex2(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_specification (
  specification_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  specification_isFormal BOOL NOT NULL DEFAULT 0,
  specification_name TEXT NULL,
  specification_description TEXT NULL,
  PRIMARY KEY(specification_id),
  INDEX spec_FKIndex1(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test (
  test_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  user_id INTEGER UNSIGNED NOT NULL,
  folder_id INTEGER UNSIGNED NOT NULL,
  test_name Varchar(60) NOT NULL,
  test_description LONGBLOB NOT NULL,
  test_priority INTEGER UNSIGNED NOT NULL DEFAULT 99,
  test_canonicalPath TEXT NOT NULL,
  test_prerequisites TEXT NOT NULL,
  test_estimatedTime BIGINT UNSIGNED NOT NULL DEFAULT 0,
  PRIMARY KEY(test_id),
  INDEX table_test_FKIndex1(folder_id),
  INDEX table_test_FKIndex2(user_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_requirement_specification (
  requirement_id INTEGER UNSIGNED NOT NULL,
  specification_id INTEGER UNSIGNED NOT NULL,
  INDEX requirement_spec_FKIndex1(requirement_id),
  INDEX requirement_specification_FKIndex2(specification_id),
  FOREIGN KEY(requirement_id)
    REFERENCES table_requirement(requirement_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(specification_id)
    REFERENCES table_specification(specification_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_schedule (
  schedule_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  schedule_name Varchar(60) NOT NULL,
  schedule_description LONGBLOB NOT NULL,
  schedule_nextStartDate DATETIME NULL,
  campaign_id INTEGER UNSIGNED NOT NULL,
  user_id INTEGER UNSIGNED NOT NULL,
  schedule_enabled BOOL NOT NULL DEFAULT 1,
  schedule_every TEXT NOT NULL,
  schedule_at TEXT NULL,
  agent_id INTEGER UNSIGNED NOT NULL,
  sut_id INTEGER UNSIGNED NOT NULL,
  schedule_conf TEXT NULL,
  PRIMARY KEY(schedule_id),
  INDEX table_schedule_FKIndex1(campaign_id),
  INDEX table_schedule_FKIndex2(user_id),
  INDEX table_schedule_FKIndex3(agent_id),
  FOREIGN KEY(campaign_id)
    REFERENCES table_campaign(campaign_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(agent_id)
    REFERENCES table_agent(agent_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(sut_id)
    REFERENCES table_sut(sut_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_campaign_session (
  campaign_session_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  user_id INTEGER UNSIGNED NOT NULL,
  campaign_id INTEGER UNSIGNED,
  sut_id INTEGER UNSIGNED NOT NULL,
  campaign_session_name TEXT NULL,
  campaign_session_startDate DATETIME NULL,
  campaign_session_stopDate DATETIME NULL,
  campaign_session_status INTEGER UNSIGNED NOT NULL DEFAULT 1,
  campaign_session_conf TEXT NULL,
  schedule_id INTEGER UNSIGNED,
  agent_id INTEGER UNSIGNED,
  PRIMARY KEY(campaign_session_id),
  INDEX campaign_session_FKIndex1(sut_id),
  INDEX campaign_session_FKIndex2(campaign_id),
  INDEX campaign_session_FKIndex3(user_id),
  INDEX campaign_session_FKIndex4(schedule_id),
  INDEX campaign_session_FKIndex5(agent_id),
  FOREIGN KEY(campaign_id)
    REFERENCES table_campaign(campaign_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(sut_id)
    REFERENCES table_sut(sut_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(schedule_id)
    REFERENCES table_schedule(schedule_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(agent_id)
    REFERENCES table_agent(agent_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;


CREATE TABLE table_testcase (
  testcase_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  test_id INTEGER UNSIGNED NOT NULL,
  testcase_index INTEGER UNSIGNED NOT NULL,
  testcase_name TEXT NULL,
  testcase_implemented BOOL NOT NULL DEFAULT 0,
  testcase_steps TEXT NULL,
  testcase_description TEXT NULL, 
  testcase_useDescAsTestplan BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(testcase_id),
  INDEX testcase_FKIndex1(test_id),
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test_dependencies (
  test_id INTEGER UNSIGNED NOT NULL,
  dependsFromTest_id INTEGER UNSIGNED NOT NULL,
  INDEX test_dependencies_FKIndex1(test_id),
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test_attr_boolean (
  test_id INTEGER UNSIGNED NOT NULL,
  attr_boolean_id INTEGER UNSIGNED NOT NULL,
  test_attr_boolean_value BOOL NOT NULL DEFAULT 0,
  INDEX test_attr_boolean_FKIndex1(attr_boolean_id),
  INDEX test_attr_boolean_FKIndex2(test_id),
  FOREIGN KEY(attr_boolean_id)
    REFERENCES table_attr_boolean(attr_boolean_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test_attr_string (
  test_id INTEGER UNSIGNED NOT NULL,
  attr_string_id INTEGER UNSIGNED NOT NULL,
  test_attr_string_value TEXT NOT NULL,
  INDEX test_attr_string_FKIndex1(attr_string_id),
  INDEX test_attr_string_FKIndex2(test_id),
  FOREIGN KEY(attr_string_id)
    REFERENCES table_attr_string(attr_string_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test_attr_integer (
  test_id INTEGER UNSIGNED NOT NULL,
  attr_integer_id INTEGER UNSIGNED NOT NULL,
  test_attr_integer_value INTEGER UNSIGNED NOT NULL,
  INDEX test_attr_integer_FKIndex2(test_id),
  INDEX test_attr_integer_FKIndex1(attr_integer_id),
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(attr_integer_id)
    REFERENCES table_attr_integer(attr_integer_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_specification_test (
  specification_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  INDEX specification_test_FKIndex1(test_id),
  INDEX specification_test_FKIndex2(specification_id),
  FOREIGN KEY(specification_id)
    REFERENCES table_specification(specification_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test_campaign (
  campaign_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  INDEX testcase_campaign_FKIndex2(campaign_id),
  INDEX testcase_campaign_FKIndex1(test_id),
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(campaign_id)
    REFERENCES table_campaign(campaign_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_testcase_execution (
  testcase_execution_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  testcase_id INTEGER UNSIGNED NOT NULL,
  testcase_execution_result INTEGER UNSIGNED NOT NULL,
  testcase_execution_message MEDIUMTEXT NULL,
  testcase_execution_trace LONGBLOB NULL,
  PRIMARY KEY(testcase_execution_id),
  INDEX testcase_execution_FKIndex1(testcase_id),
  INDEX testcase_execution_FKIndex2(campaign_session_id),
  FOREIGN KEY(testcase_id)
    REFERENCES table_testcase(testcase_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(campaign_session_id)
    REFERENCES table_campaign_session(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test_execution (
  test_execution_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  test_id INTEGER UNSIGNED NOT NULL,
  test_execution_result INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(test_execution_id),
  INDEX test_execution_FKIndex1(test_id),
  INDEX test_execution_FKIndex2(campaign_session_id),
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(campaign_session_id)
    REFERENCES table_campaign_session(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test_execution_defect (
  defect_id INTEGER UNSIGNED NOT NULL,
  test_execution_id INTEGER UNSIGNED NOT NULL,
  INDEX test_execution_defect_FKIndex1(test_execution_id),
  FOREIGN KEY(test_execution_id)
    REFERENCES table_test_execution(test_execution_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_campaign_session_ccemails (
  campaign_session_id INTEGER UNSIGNED NOT NULL,
  user_id INTEGER UNSIGNED NOT NULL,
  INDEX notification_FKIndex1(campaign_session_id),
  INDEX notification_FKIndex2(user_id),
  FOREIGN KEY(campaign_session_id)
    REFERENCES table_campaign_session(campaign_session_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_schedule_ccemails (
  schedule_id INTEGER UNSIGNED NOT NULL,
  user_id INTEGER UNSIGNED NOT NULL,
  INDEX notification_FKIndex1(schedule_id),
  INDEX notification_FKIndex2(user_id),
  FOREIGN KEY(schedule_id)
    REFERENCES table_schedule(schedule_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  FOREIGN KEY(user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_testcase_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  testcase_id INTEGER UNSIGNED NOT NULL,
  attachment_name TEXT NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_added DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(attachment_id),
  INDEX testcase_attachment_FKIndex1(testcase_id),
  FOREIGN KEY(testcase_id)
    REFERENCES table_testcase(testcase_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_test_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  test_id INTEGER UNSIGNED NOT NULL,
  attachment_name TEXT NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_added DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(attachment_id),
  INDEX test_attachment_FKIndex1(test_id),
  FOREIGN KEY(test_id)
    REFERENCES table_test(test_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_folder_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  folder_id INTEGER UNSIGNED NOT NULL,
  attachment_name TEXT NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_added DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(attachment_id),
  INDEX test_attachment_FKIndex1(folder_id),
  FOREIGN KEY(folder_id)
    REFERENCES table_folder(folder_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_category_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  category_id INTEGER UNSIGNED NOT NULL,
  attachment_name TEXT NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_added DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(attachment_id),
  INDEX test_attachment_FKIndex1(category_id),
  FOREIGN KEY(category_id)
    REFERENCES table_category(category_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_testcase_execution_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  testcase_execution_id INTEGER UNSIGNED NOT NULL,
  attachment_name TEXT NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_added DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(attachment_id),
  INDEX test_attachment_FKIndex1(testcase_execution_id),
  FOREIGN KEY(testcase_execution_id)
    REFERENCES table_testcase_execution(testcase_execution_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_change (
  type TINYINT NOT NULL,
  id INTEGER UNSIGNED NOT NULL,
  date DATETIME NOT NULL,
  user_id INTEGER UNSIGNED NOT NULL,
  action TINYINT NOT NULL,
  information TEXT NULL,
  FOREIGN KEY(user_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;	