UPDATE table_version SET version_number = '36' WHERE version_id = '1';

RENAME TABLE table_defect_attachment TO table_defect_integrated_attachment;
RENAME TABLE table_defect_attachment_content TO table_defect_integrated_attachment_content;

ALTER TABLE table_category_attachment ADD hidden BOOL NOT NULL DEFAULT 0;
ALTER TABLE table_folder_attachment ADD hidden BOOL NOT NULL DEFAULT 0;
ALTER TABLE table_requirement_attachment ADD hidden BOOL NOT NULL DEFAULT 0;
ALTER TABLE table_specification_attachment ADD hidden BOOL NOT NULL DEFAULT 0;
ALTER TABLE table_test_attachment ADD hidden BOOL NOT NULL DEFAULT 0;
ALTER TABLE table_testcase_attachment ADD hidden BOOL NOT NULL DEFAULT 0;
ALTER TABLE table_testcase_execution_attachment ADD hidden BOOL NOT NULL DEFAULT 0;
ALTER TABLE table_campaign_session_attachment ADD hidden BOOL NOT NULL DEFAULT 0;
ALTER TABLE table_defect_integrated_attachment ADD hidden BOOL NOT NULL DEFAULT 0;

CREATE TABLE table_company_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  company_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX company_attachment_lockedby_FKIndex(locked_by),
  FOREIGN KEY(locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX company_attachment_FKIndex1(company_id),
  FOREIGN KEY(company_id)
    REFERENCES table_company(company_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_company_attachment_content (
  content_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_submitted DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(content_id),
  INDEX company_content_FKIndex1(attachment_id),
  FOREIGN KEY(attachment_id)
    REFERENCES table_company_attachment(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX company_content_FKIndex2(author_id),
  FOREIGN KEY(author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_sut_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  sut_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX sut_attachment_lockedby_FKIndex(locked_by),
  FOREIGN KEY(locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX sut_attachment_FKIndex1(sut_id),
  FOREIGN KEY(sut_id)
    REFERENCES table_sut(sut_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_sut_attachment_content (
  content_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_submitted DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(content_id),
  INDEX sut_content_FKIndex1(attachment_id),
  FOREIGN KEY(attachment_id)
    REFERENCES table_sut_attachment(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX sut_content_FKIndex2(author_id),
  FOREIGN KEY(author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_project_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  project_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX project_attachment_lockedby_FKIndex(locked_by),
  FOREIGN KEY(locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX project_attachment_FKIndex1(project_id),
  FOREIGN KEY(project_id)
    REFERENCES table_project(project_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_project_attachment_content (
  content_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_submitted DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(content_id),
  INDEX project_content_FKIndex1(attachment_id),
  FOREIGN KEY(attachment_id)
    REFERENCES table_project_attachment(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX project_content_FKIndex2(author_id),
  FOREIGN KEY(author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_task_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  task_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX task_attachment_lockedby_FKIndex(locked_by),
  FOREIGN KEY(locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX task_attachment_FKIndex1(task_id),
  FOREIGN KEY(task_id)
    REFERENCES table_task(task_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_task_attachment_content (
  content_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_submitted DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(content_id),
  INDEX task_content_FKIndex1(attachment_id),
  FOREIGN KEY(attachment_id)
    REFERENCES table_task_attachment(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX task_content_FKIndex2(author_id),
  FOREIGN KEY(author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_sprint_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  sprint_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX sprint_attachment_lockedby_FKIndex(locked_by),
  FOREIGN KEY(locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX sprint_attachment_FKIndex1(sprint_id),
  FOREIGN KEY(sprint_id)
    REFERENCES table_sprint(sprint_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_sprint_attachment_content (
  content_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_submitted DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(content_id),
  INDEX sprint_content_FKIndex1(attachment_id),
  FOREIGN KEY(attachment_id)
    REFERENCES table_sprint_attachment(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX sprint_content_FKIndex2(author_id),
  FOREIGN KEY(author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_campaign_attachment (
  attachment_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  campaign_id INTEGER UNSIGNED NOT NULL,
  attachment_name VARCHAR(128) CHARACTER SET utf8 NOT NULL,
  locked_by INTEGER UNSIGNED DEFAULT NULL,
  hidden BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(attachment_id),
  INDEX campaign_attachment_lockedby_FKIndex(locked_by),
  FOREIGN KEY(locked_by)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX campaign_attachment_FKIndex1(campaign_id),
  FOREIGN KEY(campaign_id)
    REFERENCES table_campaign(campaign_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;

CREATE TABLE table_campaign_attachment_content (
  content_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  attachment_id INTEGER UNSIGNED NOT NULL,
  attachment_data LONGBLOB NOT NULL,
  date_submitted DATETIME NULL,
  size INTEGER UNSIGNED NOT NULL,
  author_id INTEGER UNSIGNED NOT NULL,
  revision INTEGER UNSIGNED NOT NULL DEFAULT 1,
  PRIMARY KEY(content_id),
  INDEX campaign_content_FKIndex1(attachment_id),
  FOREIGN KEY(attachment_id)
    REFERENCES table_campaign_attachment(attachment_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION,
  INDEX campaign_content_FKIndex2(author_id),
  FOREIGN KEY(author_id)
    REFERENCES table_user(user_id)
      ON DELETE CASCADE
      ON UPDATE NO ACTION
)
ENGINE=InnoDB;


