<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="html" indent="yes" encoding="UTF-8"/>

  <!-- global variables -->
  <xsl:variable name="codebase" select="specifications/@codebase" />
  <xsl:variable name="bugtrackingType" select="specifications/@bugTrackingType" />
  <xsl:variable name="requirementTrackingType" select="specifications/@requirementTrackingType" />
  <xsl:variable name="specificationInLifecycle" select="specifications/@specificationInLifecycle" />

  <xsl:include href="#export_absolute_path#xsl/lib.xslt"/>
  <xsl:include href="#export_absolute_path#xsl/specificationHTML_Lib.xslt"/>
  <xsl:template match="/">

    <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">

	  <head>		
		<title>XStudio Report</title>
		<meta name="description" content="XStudio"/>
		<meta name="keywords" content="xstudio, report"/>
		<meta name="author" lang="en" content="XQual"/>
		<meta name="robots" content="noarchive"/>
		<meta http-equiv="Pragma" content="no-cache"/>
	    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
		<meta http-equiv="Content-Language" content="en"/>		
		<link rel="stylesheet" href="#css#" type="text/css"/>		
	  </head>

      <body>
        <xsl:variable name="domain"                select="specifications/@domain" />
        <xsl:variable name="graphInReportsEnabled" select="specifications/@graphInReportsEnabled" />
        <xsl:variable name="documentDate"          select="specifications/@date" />
        <xsl:variable name="documentAuthor"        select="specifications/@author" />

        <div align="center">
          <table width="100%">
            <tr>
              <td valign="top"><img src="#images#/#company_logo#"/></td>
            </tr>
          </table>
          <br/>

          <xsl:if test="$domain = 1">
            <span class="report_title">#specification.Complete_Specification#</span><br/>
          </xsl:if>
          <xsl:if test="$domain = 3">
            <span class="report_title">#specification.Folder_Specification#</span><br/>
          </xsl:if>
          <span class="report_subtitle">Complete With Statistics</span><br/>
          <span>Generated by <b><xsl:value-of select="$documentAuthor" /></b> (<b><xsl:value-of select="$documentDate" /></b>)</span><br/>

          <xsl:call-template name="big_hr"/>
          <a class="report_table_of_content" href="#_metrics">#specification.Metrics#</a><br/>
          <a class="report_table_of_content" href="#_summary">#specification.Summary#</a><br/>
          <a class="report_table_of_content" href="#_details">#specification.Details#</a><br/>
          <a class="report_table_of_content" href="#_perpriority">#specification.Per_priority#</a><br/>
          <a class="report_table_of_content" href="#_perstatus">#specification.Per_status#</a><br/>
          <a class="report_table_of_content" href="#_matrix">#specification.Traceability_Matrix#</a><br/>
          <a class="report_table_of_content" href="#_tbd">#specification.To_be_defined#</a><br/>
          <a class="report_table_of_content" href="#_abbr">#specification.Abbreviations#</a><br/>
          <xsl:call-template name="big_hr"/>
        </div>

        <a name="_metrics"/>
        <h1>#specification.Metrics#</h1>
        <xsl:call-template name="generateGlobalMetrics"/>


        <a name="_summary"/>
        <h1>#specification.Summary#</h1>
        <xsl:call-template name="insertCharts">
          <xsl:with-param name="graphInReportsEnabled" select="$graphInReportsEnabled"/>
          <xsl:with-param name="domain" select="$domain"/>
        </xsl:call-template>

        
        <table width="100%">
          <!-- ******************* SPECIFICATION SUMMARY *************************** -->
          <tr>
            <td class="table_data_header" width="90%">#specification.Folder#</td>
            <td class="table_data_header">#specification.Nb_specifications#</td>
            <td class="table_data_header">#specification.status.New#</td>
            <td class="table_data_header">#specification.status.Acknowledged#</td>
            <td class="table_data_header">#specification.status.Approved#</td>
            <td class="table_data_header">#specification.priority.High#</td>
            <td class="table_data_header">#specification.priority.Normal#</td>
            <td class="table_data_header">#specification.priority.Low#</td>
          </tr>

          <xsl:for-each select="specifications/folder">
            <xsl:call-template name="generateSummaryFolder">
              <xsl:with-param name="parentName" select="''"/>
              <xsl:with-param name="tab" select="''"/>
            </xsl:call-template>
          </xsl:for-each>
        </table>


        <a name="_details"/>
        <h1>#specification.Details#</h1>
        <!-- ******************* SPECIFICATION DETAILS *************************** -->
        <!-- Folders -->
        <xsl:for-each select="specifications/folder"> <!-- recursive call to display folders -->
          <xsl:if test="count(descendant::specification) > 0">
            <xsl:call-template name="generateDetailsFolder">
              <xsl:with-param name="parentName" select="''"/>
            </xsl:call-template>
          </xsl:if>
        </xsl:for-each>


        <a name="_perpriority"/>
        <h1>#specification.Per_priority#</h1>
        <!-- ******************* specification PER PRIORITY *************************** -->
        <table width="100%">
          <tr>
            <td class="table_data_header">#specification.Specifications#</td>
            <td class="table_data_header">#specification.Priority#</td>
            <td class="table_data_header">#specification.Status#</td>
          </tr>
          <xsl:for-each select="//specification">
              <xsl:sort select="@priority" data-type="number"/>

            <xsl:variable name="specificationId"       select="@id" />
            <xsl:variable name="specificationName"     select="@name" />
            <xsl:variable name="specificationPriority" select="@priority" />
            <xsl:variable name="specificationStatus"   select="@status" />

            <!-- specifications -->
            <tr>
              <td class="table_data_subheader">
                <!-- anchor link -->
                <a>
                  <xsl:attribute name="href">
                    <xsl:call-template name="generateSharpUniqueId">
                      <xsl:with-param name="type" select="'specification'"/>
                      <xsl:with-param name="id" select="@id"/>
                    </xsl:call-template>
                  </xsl:attribute>
                  [S_<xsl:value-of select="$specificationId" />] <xsl:value-of select="$specificationName" />
                </a>
              </td>
              <td class="table_data_subheader">
                <xsl:call-template name="specificationPriorityToString"><xsl:with-param name="priority" select="$specificationPriority"/></xsl:call-template>
              </td>
              <td class="table_data_subheader">
                <xsl:call-template name="specificationStatusToString"><xsl:with-param name="status" select="$specificationStatus"/></xsl:call-template>
              </td>

            </tr>
          </xsl:for-each>
        </table>




        <a name="_perstatus"/>
        <h1>#specification.Per_status#</h1>
        <!-- ******************* specification PER STATUS *************************** -->
        <table width="100%">
          <tr>
            <td class="table_data_header">#specification.Specifications#</td>
            <td class="table_data_header">#specification.Priority#</td>
            <td class="table_data_header">#specification.Status#</td>
          </tr>
          <xsl:for-each select="//specification">
              <xsl:sort select="@status" data-type="number"/>

            <xsl:variable name="specificationId"       select="@id" />
            <xsl:variable name="specificationName"     select="@name" />
            <xsl:variable name="specificationPriority" select="@priority" />
            <xsl:variable name="specificationStatus"   select="@status" />

            <!-- specifications -->
            <tr>
              <td class="table_data_subheader">
                <!-- anchor link -->
                <a>
                  <xsl:attribute name="href">
                    <xsl:call-template name="generateSharpUniqueId">
                      <xsl:with-param name="type" select="'specification'"/>
                      <xsl:with-param name="id" select="@id"/>
                    </xsl:call-template>
                  </xsl:attribute>
                  [S_<xsl:value-of select="$specificationId" />] <xsl:value-of select="$specificationName" />
                </a>
              </td>
              <td class="table_data_subheader">
                <xsl:call-template name="specificationPriorityToString"><xsl:with-param name="priority" select="$specificationPriority"/></xsl:call-template>
              </td>
              <td class="table_data_subheader">
                <xsl:call-template name="specificationStatusToString"><xsl:with-param name="status" select="$specificationStatus"/></xsl:call-template>
              </td>

            </tr>
          </xsl:for-each>
        </table>

        <a name="_matrix"/>
        <h1>#specification.Traceability_Matrix#</h1>
        <!-- ******************* specification TRACEABILITY MATRIX *************************** -->
        <table width="100%">
          <tr>
            <td class="table_data_header">#specification.Specifications#</td>
            <td class="table_data_header">#specification.Priority#</td>
            <td class="table_data_header">#specification.Status#</td>
            <td class="table_data_header">#specification.Tests#</td>
          </tr>
          <xsl:for-each select="//specification">
              <xsl:sort select="@id" data-type="number"/>

            <xsl:variable name="specificationId"       select="@id" />
            <xsl:variable name="specificationName"     select="@name" />
            <xsl:variable name="specificationPriority" select="@priority" />
            <xsl:variable name="specificationStatus"   select="@status" />

            <!-- specifications -->
            <tr>
              <td class="table_data_subheader">
                <!-- anchor link -->
                <a>
                  <xsl:attribute name="href">
                    <xsl:call-template name="generateSharpUniqueId">
                      <xsl:with-param name="type" select="'specification'"/>
                      <xsl:with-param name="id" select="@id"/>
                    </xsl:call-template>
                  </xsl:attribute>
                  [S_<xsl:value-of select="$specificationId" />] <xsl:value-of select="$specificationName" />
                </a>
              </td>
              <td class="table_data_subheader">
                <xsl:call-template name="specificationPriorityToString"><xsl:with-param name="priority" select="$specificationPriority"/></xsl:call-template>
              </td>
              <td class="table_data_subheader">
                <xsl:call-template name="specificationStatusToString"><xsl:with-param name="status" select="$specificationStatus"/></xsl:call-template>
              </td>
              <xsl:call-template name="generateListOfUniqueIds">
                <xsl:with-param name="nodeSet" select="test"/>
                <xsl:with-param name="prefix" select="'T_'"/>
              </xsl:call-template>
            </tr>
          </xsl:for-each>
        </table>
        <br/><br/><br/><br/>
        
        <a name="_tbd"/>
        <xsl:call-template name="generateTBD"/>
        <br/><br/><br/>
       
        <a name="_abbr"/>
        <xsl:call-template name="generateABBR"/>
        <br/><br/><br/>
      </body>
    </html>

  </xsl:template>









  <xsl:template name="generateSummaryFolder">
    <xsl:param name="parentName"/>
    <xsl:param name="tab"/>

    <xsl:variable name="folderName" select="@name" />

    <tr>
      <td class="table_data_content">
        <!-- anchor link -->
        <xsl:value-of disable-output-escaping="yes" select="$tab" />
        <a>
        <xsl:attribute name="href">
          <xsl:call-template name="generateSharpUniqueId">
            <xsl:with-param name="type" select="'folder'"/>
            <xsl:with-param name="id" select="@id"/>
          </xsl:call-template>
        </xsl:attribute>
        <xsl:value-of select="$folderName" />
        </a>
      </td>
      <xsl:call-template name="generateNbTd">
        <xsl:with-param name="nodeSet" select="descendant-or-self::specification"/>
        <xsl:with-param name="tdStyle" select="'table_data_content'"/>
      </xsl:call-template>
      <xsl:call-template name="generate3StatusTd">
        <xsl:with-param name="nodeSet" select="descendant-or-self::specification"/>
        <xsl:with-param name="tdStyle" select="'table_data_content'"/>
      </xsl:call-template>
      <xsl:call-template name="generate3PriorityTd">
        <xsl:with-param name="nodeSet" select="descendant-or-self::specification"/>
        <xsl:with-param name="tdStyle" select="'table_data_content'"/>
      </xsl:call-template>
    </tr>

    <xsl:for-each select="folder">
      <xsl:call-template name="generateSummaryFolder">
        <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
        <xsl:with-param name="tab" select="concat($tab, '&#160;&#160;&#160;&#160;')"/>
      </xsl:call-template>
    </xsl:for-each>
  </xsl:template>


  <xsl:template name="generateFolderSubSummary">
    <xsl:param name="parentName"/>

    <table width="100%">
      <tr>
        <td class="table_data_header">#specification.Specifications#</td>
        <td class="table_data_header">#specification.Priority#</td>
        <td class="table_data_header">#specification.Status#</td>
      </tr>
      <xsl:for-each select="specification">
        <xsl:variable name="specificationId"       select="@id" />
        <xsl:variable name="specificationName"     select="@name" />
        <xsl:variable name="specificationPriority" select="@priority" />
        <xsl:variable name="specificationStatus"   select="@status" />

        <!-- Specifications -->
        <tr>
          <td class="table_data_subheader">
            <!-- anchor link -->
            <a>
              <xsl:attribute name="href">
                <xsl:call-template name="generateSharpUniqueId">
                  <xsl:with-param name="type" select="'specification'"/>
                  <xsl:with-param name="id" select="@id"/>
                </xsl:call-template>
              </xsl:attribute>
              [S_<xsl:value-of select="$specificationId" />] <xsl:value-of select="$specificationName" />
            </a>
          </td>
          <td class="table_data_subheader">
            <xsl:call-template name="specificationPriorityToString"><xsl:with-param name="priority" select="$specificationPriority"/></xsl:call-template>
          </td>
          <td class="table_data_subheader">
            <xsl:call-template name="specificationStatusToString"><xsl:with-param name="status" select="$specificationStatus"/></xsl:call-template>
          </td>

        </tr>
      </xsl:for-each>
    </table>
  </xsl:template>



  <xsl:template name="generateDetailsFolder">
    <xsl:param name="parentName"/>
    
    <xsl:variable name="folderName" select="@name" />
    <xsl:variable name="folderDescription" select="description" />

    <xsl:if test="count(specification) > 0">
      <a>
        <xsl:attribute name="name">
          <xsl:call-template name="generateUniqueId">
            <xsl:with-param name="type" select="'folder'"/>
            <xsl:with-param name="id" select="@id"/>
          </xsl:call-template>
        </xsl:attribute>
      </a>
      
      <h3><xsl:value-of select="concat($parentName, '/', $folderName)" /></h3>
      <!-- folder description -->
      <p><xsl:value-of disable-output-escaping="yes" select="$folderDescription" /></p>

      <xsl:call-template name="generateAttachments">
        <xsl:with-param name="parentType" select="'FL_'"/>
        <xsl:with-param name="attachmentIcon" select="'#images#/IconAttachment.gif'"/>
      </xsl:call-template>

      <xsl:call-template name="generateFolderSubSummary">
        <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
      </xsl:call-template>

      <xsl:call-template name="generateSpecificationsDetailsFromCurrentLevel"/>
    </xsl:if>

    <!-- Recursivity -->
    <xsl:for-each select="folder">
      <xsl:if test="count(descendant::specification) > 0">
        <xsl:call-template name="generateDetailsFolder">
          <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
        </xsl:call-template>
      </xsl:if>
    </xsl:for-each>
  </xsl:template>

  <xsl:template name="generateGlobalMetrics">
    <xsl:variable name="nbGlobalspecifications"          select="count(specifications/descendant::specification)"/>

    <xsl:variable name="nbGlobalspecificationsNew"       select="count(specifications/descendant::specification[@status='10'])"/>
    <xsl:variable name="nbGlobalspecificationsAck"       select="count(specifications/descendant::specification[@status='20'])"/>
    <xsl:variable name="nbGlobalspecificationsApproved"  select="count(specifications/descendant::specification[@status='30'])"/>

    <xsl:variable name="nbGlobalspecificationsHigh"      select="count(specifications/descendant::specification[@priority='10'])"/>
    <xsl:variable name="nbGlobalspecificationsNormal"    select="count(specifications/descendant::specification[@priority='20'])"/>
    <xsl:variable name="nbGlobalspecificationsLow"       select="count(specifications/descendant::specification[@priority='30'])"/>

    <xsl:if test="$nbGlobalspecifications != 0">
      <table>
        <tr>
          <td class="table_label">#specification.Nb_specifications#:</td>
          <td class="table_value" width="8px">&#160;</td>
          <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobalspecifications"/></td>
        </tr>
      </table>
      <br/>
      <table>
        <tr>
          <td valign="top">
            <table>
                <tr><td colspan="2" class="table_label"><u>#specification.Status#:</u></td></tr>
                <tr>
                  <td class="table_label">#specification.status.New#:</td>
                  <td class="table_value" width="8px">&#160;</td>
                  <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobalspecificationsNew"/></td>
                </tr>
                <tr>
                  <td class="table_label">#specification.status.Acknowledged#:</td>
                  <td class="table_value" width="8px">&#160;</td>
                  <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobalspecificationsAck"/></td>
                </tr>
                <tr>
                  <td class="table_label">#specification.status.Approved#:</td>
                  <td class="table_value" width="8px">&#160;</td>
                  <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobalspecificationsApproved"/></td>
                </tr>
            </table>
          </td>
          <td width="50px">&#160;</td>
          <td valign="top">
            <table>
                <tr><td colspan="2" class="table_label"><u>#specification.Priority#:</u></td></tr>
                <tr>
                  <td class="table_label">#specification.priority.High#:</td>
                  <td class="table_value" width="8px">&#160;</td>
                  <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobalspecificationsHigh"/></td>
                </tr>
                <tr>
                  <td class="table_label">#specification.priority.Normal#:</td>
                  <td class="table_value" width="8px">&#160;</td>
                  <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobalspecificationsNormal"/></td>
                </tr>
                <tr>
                  <td class="table_label">#specification.priority.Low#:</td>
                  <td class="table_value" width="8px">&#160;</td>
                  <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobalspecificationsLow"/></td>
                </tr>
            </table>
          </td>
        </tr>
      </table>
    </xsl:if>
    <xsl:if test="$nbGlobalspecifications = 0">
      <h3>no specification available</h3>
    </xsl:if>
  </xsl:template>



  <xsl:template name="generateFolderDetails">
    <xsl:variable name="nbSpecifications"   select="count(descendant-or-self::specification)"/>

    <xsl:if test="$nbSpecifications != 0">
      <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="$nbSpecifications"/></td>
    </xsl:if>
    <xsl:if test="$nbSpecifications = 0">
      <td class="table_data_content"></td>
    </xsl:if>
  </xsl:template>

</xsl:stylesheet>