<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="html" indent="yes" encoding="UTF-8"/>

  <!-- global variables -->
  <xsl:variable name="codebase" select="tasks/@codebase" />
  <xsl:variable name="bugtrackingType" select="tasks/@bugTrackingType" />
  <xsl:variable name="requirementTrackingType" select="tasks/@requirementTrackingType" />
  <xsl:variable name="specificationInLifecycle" select="tasks/@specificationInLifecycle" />

  <xsl:include href="#export_absolute_path#xsl/lib.xslt"/>
  <xsl:include href="#export_absolute_path#xsl/taskHTML_Lib.xslt"/>
  <xsl:template match="/">

    <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">

	  <head>		
		<title>XStudio Report</title>
		<meta name="description" content="XStudio"/>
		<meta name="keywords" content="xstudio, report"/>
		<meta name="author" lang="en" content="XQual"/>
		<meta name="robots" content="noarchive"/>
		<meta http-equiv="Pragma" content="no-cache"/>
	  <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
		<meta http-equiv="Content-Language" content="en"/>		
		<link rel="stylesheet" href="#css#" type="text/css"/>		
	  </head>

      <body>
        <xsl:variable name="nbProject"             select="count(tasks/project)" />
        <xsl:variable name="domain"                select="tasks/@domain" />
        <xsl:variable name="graphInReportsEnabled" select="tasks/@graphInReportsEnabled" />
        <xsl:variable name="documentDate"          select="tasks/@date" />
        <xsl:variable name="documentAuthor"        select="tasks/@author" />

        <div align="center">
          <table width="100%">
            <tr>
              <td valign="top"><img src="#images#/#company_logo#"/></td>
            </tr>
          </table>
          <br/>

          <xsl:if test="$domain = 1">
            <span class="report_title">#task.Complete_Task#</span><br/>
          </xsl:if>
          <xsl:if test="$domain = 2">
           <span class="report_title">#task.Project_Task#</span><br/>
          </xsl:if>
          <xsl:if test="$domain = 3">
           <span class="report_title">#task.Sprint_Task#</span><br/>
          </xsl:if>
          <span class="report_subtitle">Complete With Statistics"</span><br/>
          <span>Generated by <b><xsl:value-of select="$documentAuthor" /></b> (<b><xsl:value-of select="$documentDate" /></b>)</span><br/>

          <xsl:call-template name="big_hr"/>
          <a class="report_table_of_content" href="#_metrics">#task.Metrics#</a><br/>
          <a class="report_table_of_content" href="#_summary">#task.Summary#</a><br/>
          <a class="report_table_of_content" href="#_details">#task.Details#</a><br/>
          <a class="report_table_of_content" href="#_tbd">#task.To_be_defined#</a><br/>
          <a class="report_table_of_content" href="#_abbr">#task.Abbreviations#</a><br/>
          <xsl:call-template name="big_hr"/>
        </div>

        <a name="_metrics"/>
        <h1>#task.Metrics#</h1>
        <xsl:call-template name="generateGlobalMetrics"/>


        <a name="_summary"/>
        <h1>#task.Summary#</h1>
        <xsl:call-template name="insertCharts">
          <xsl:with-param name="graphInReportsEnabled" select="$graphInReportsEnabled"/>
          <xsl:with-param name="domain" select="$domain"/>
        </xsl:call-template>


        <table width="100%">
          <!-- ******************* TASK SUMMARY *************************** -->
          <xsl:if test="$nbProject > 0">
            <tr>
              <td rowspan="2" class="table_data_header" width="90%">#task.Project#</td>
              <td rowspan="2" class="table_data_header">#task.Nb_tasks#</td>
              <td colspan="11" class="table_data_header">#task.Priority#</td>
            </tr>
            <tr>
              <td class="table_data_header">&#160;&#160;0&#160;&#160;</td>
              <td class="table_data_header">&#160;&#160;1&#160;&#160;</td>
              <td class="table_data_header">&#160;&#160;2&#160;&#160;</td>
              <td class="table_data_header">&#160;&#160;3&#160;&#160;</td>
              <td class="table_data_header">&#160;&#160;4&#160;&#160;</td>
              <td class="table_data_header">&#160;&#160;5&#160;&#160;</td>
              <td class="table_data_header">&#160;&#160;6&#160;&#160;</td>
              <td class="table_data_header">&#160;&#160;7&#160;&#160;</td>
              <td class="table_data_header">&#160;&#160;8&#160;&#160;</td>
              <td class="table_data_header">&#160;&#160;9&#160;&#160;</td>
              <td class="table_data_header">&#160;&#160;10&#160;&#160;</td>
            </tr>

            <xsl:for-each select="tasks/project">
              <xsl:variable name="projectName" select="@name" />

              <!-- Projects -->
              <tr>
                <td class="table_data_subheader">
                  <!-- anchor link -->
                  <a>
                    <xsl:attribute name="href">
                      <xsl:call-template name="generateSharpUniqueId">
                        <xsl:with-param name="type" select="'project'"/>
                        <xsl:with-param name="id" select="@id"/>
                      </xsl:call-template>
                    </xsl:attribute>
                    <xsl:value-of select="$projectName" />
                  </a>
                </td>
                <xsl:call-template name="generateNbTd">
                  <xsl:with-param name="nodeSet" select="descendant-or-self::task"/>
                  <xsl:with-param name="tdStyle" select="'table_data_subheader'"/>
                </xsl:call-template>
                <xsl:call-template name="generate11PriorityTd">
                  <xsl:with-param name="nodeSet" select="descendant-or-self::task"/>
                  <xsl:with-param name="tdStyle" select="'table_data_subheader'"/>
                </xsl:call-template>
              </tr>

              <!-- Sprints -->
              <xsl:for-each select="sprint">
                <xsl:call-template name="generateSummarySprint">
                  <xsl:with-param name="parentName" select="$projectName"/>
                  <xsl:with-param name="tab" select="''"/>
                </xsl:call-template>
              </xsl:for-each>

            </xsl:for-each>
          </xsl:if>

        </table>


        <a name="_details"/>
        <h1>#task.Details#</h1>
        <!-- ******************* TASK DETAILS *************************** -->
        <xsl:if test="$nbProject > 0">
          <xsl:for-each select="tasks/project">
            <xsl:variable name="projectName" select="@name" />
            <xsl:variable name="nbTasksInThisProject" select="count(descendant::task)" />
            <xsl:variable name="nbFoldersInThisProject" select="count(descendant::folder)" />

            <xsl:if test="$nbTasksInThisProject > 0">
              <!-- Projects -->
              <a>
                <xsl:attribute name="name">
                  <xsl:call-template name="generateUniqueId">
                    <xsl:with-param name="type" select="'project'"/>
                    <xsl:with-param name="id" select="@id"/>
                  </xsl:call-template>
                </xsl:attribute>
              </a>
              <h2>
                <img src="#images#/IconProject.gif"/>&#160;
                <xsl:value-of disable-output-escaping="yes" select="$projectName" />&#160;
              </h2>

              <!-- Folders -->
              <xsl:variable name="nbFolders" select="count(folder)" />
              <xsl:for-each select="folder"> <!-- recursive call to display folders -->
                <xsl:variable name="folderName" select="@name" />
                <xsl:if test="count(descendant::task) > 0">
                  <xsl:call-template name="generateDetailsFolderWithoutProgress">
                    <xsl:with-param name="parentName" select="$projectName"/>
                  </xsl:call-template>
                </xsl:if>
              </xsl:for-each>

              <!-- Sprint -->
              <xsl:for-each select="sprint"> <!-- non-recursive call to display sprint -->
                <xsl:variable name="sprintId" select="@id" />
                <xsl:variable name="sprintName" select="@name" />

                <xsl:call-template name="generateSprintDetails">
                  <xsl:with-param name="parentName" select="$projectName"/>
                </xsl:call-template>

                <!-- Folders -->
                <xsl:if test="$nbFoldersInThisProject > 0">
                      <h2>#task.Details_per_folder#</h2>
                </xsl:if>
                <xsl:for-each select="folder"> <!-- recursive call to display folders -->
                  <xsl:if test="count(descendant::task) > 0">
                    <xsl:call-template name="generateDetailsFolder">
                      <xsl:with-param name="parentName" select="concat($projectName, '/', $sprintName)"/>
                      <xsl:with-param name="sprintId" select="$sprintId"/>
                    </xsl:call-template>
                  </xsl:if>
                </xsl:for-each>
              </xsl:for-each>
            </xsl:if>
          </xsl:for-each>
        </xsl:if>
      </body>
        <br/><br/><br/><br/>
        
        <a name="_tbd"/>
        <xsl:call-template name="generateTBD"/>
        <br/><br/><br/>
       
        <a name="_abbr"/>
        <xsl:call-template name="generateABBR"/>
        <br/><br/><br/>
    </html>

  </xsl:template>









  <xsl:template name="generateSummarySprint">
    <xsl:param name="parentName"/>
    <xsl:param name="tab"/>

    <xsl:variable name="sprintId" select="@id" />
    <xsl:variable name="sprintName" select="@name" />

    <tr>
      <td class="table_data_subsubheader">
        <!-- anchor link -->
        <xsl:value-of disable-output-escaping="yes" select="$tab" />
        <a>
        <xsl:attribute name="href">
          <xsl:call-template name="generateSharpUniqueId">
            <xsl:with-param name="type" select="'sprint'"/>
            <xsl:with-param name="id" select="@id"/>
          </xsl:call-template>
        </xsl:attribute>
        <xsl:value-of select="$sprintName" />
        </a>
      </td>
      <xsl:call-template name="generateNbTd">
        <xsl:with-param name="nodeSet" select="descendant-or-self::task"/>
        <xsl:with-param name="tdStyle" select="'table_data_subsubheader'"/>
      </xsl:call-template>
      <xsl:call-template name="generate11PriorityTd">
        <xsl:with-param name="nodeSet" select="descendant-or-self::task"/>
        <xsl:with-param name="tdStyle" select="'table_data_subsubheader'"/>
      </xsl:call-template>
    </tr>

    <xsl:for-each select="folder">
      <xsl:call-template name="generateSummaryFolder">
        <xsl:with-param name="parentName" select="concat($parentName, '/', $sprintName)"/>
        <xsl:with-param name="tab" select="concat($tab, '&#160;&#160;&#160;&#160;')"/>
        <xsl:with-param name="sprintId" select="$sprintId"/>
      </xsl:call-template>
    </xsl:for-each>
  </xsl:template>



  <xsl:template name="generateSummaryFolder">
    <xsl:param name="parentName"/>
    <xsl:param name="tab"/>
    <xsl:param name="sprintId"/>

    <xsl:variable name="folderName" select="@name" />
    <xsl:variable name="nbTasks"   select="count(descendant-or-self::task)"/>

    <xsl:if test="$nbTasks != 0">
      <tr>
        <td class="table_data_content">
          <!-- anchor link -->
          <xsl:value-of disable-output-escaping="yes" select="$tab" />
          <a>
          <xsl:attribute name="href"> <!-- must point to the combination sprint/folder -->
            <xsl:call-template name="generateSharpUniqueIdFromTwoIds">
              <xsl:with-param name="type1" select="'sprint'"/>
              <xsl:with-param name="id1"   select="$sprintId"/>
              <xsl:with-param name="type2" select="'folder'"/>
              <xsl:with-param name="id2"   select="@id"/>
            </xsl:call-template>
          </xsl:attribute>
          <xsl:value-of select="$folderName" />
          </a>
        </td>
        <xsl:call-template name="generateNbTd">
          <xsl:with-param name="nodeSet" select="descendant-or-self::task"/>
          <xsl:with-param name="tdStyle" select="'table_data_content'"/>
        </xsl:call-template>
        <xsl:call-template name="generate11PriorityTd">
          <xsl:with-param name="nodeSet" select="descendant-or-self::task"/>
          <xsl:with-param name="tdStyle" select="'table_data_content'"/>
        </xsl:call-template>
      </tr>

      <xsl:for-each select="folder">
        <xsl:call-template name="generateSummaryFolder">
          <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
          <xsl:with-param name="tab" select="concat($tab, '&#160;&#160;&#160;&#160;')"/>
          <xsl:with-param name="sprintId" select="$sprintId"/>
        </xsl:call-template>
      </xsl:for-each>

    </xsl:if>
  </xsl:template>


  <xsl:template name="generateFolderSubSummary">
    <xsl:param name="parentName"/>
    <xsl:param name="sprintId"/>

    <table width="100%">
      <tr>
        <td class="table_data_header">#task.Tasks#</td>
        <td class="table_data_header">#task.Priority#</td>
        <td class="table_data_header">#task.Estimated#</td>
        <td class="table_data_header" width="1%">#task.Progress#</td>
      </tr>
      <xsl:for-each select="task">
        <xsl:variable name="taskId"        select="@id" />
        <xsl:variable name="taskName"      select="@name" />
        <xsl:variable name="taskPriority"  select="@priority" />
        <xsl:variable name="taskEstimated" select="@estimated" />
        <xsl:variable name="taskProgress"  select="@progress" />

        <!-- Tasks -->
        <tr>
          <td class="table_data_subheader">
            <!-- anchor link -->
            <a>
              <xsl:attribute name="href">
                <xsl:call-template name="generateSharpUniqueIdFromTwoIds">
                  <xsl:with-param name="type1" select="'sprint'"/>
                  <xsl:with-param name="id1"   select="$sprintId"/>
                  <xsl:with-param name="type2" select="'task'"/>
                  <xsl:with-param name="id2"   select="@id"/>
                </xsl:call-template>
              </xsl:attribute>
              [TA_<xsl:value-of select="$taskId" />] <xsl:value-of select="$taskName" />
            </a>
          </td>
          <td class="table_data_subheader">
            <xsl:value-of select="$taskPriority" />
          </td>
          <td class="table_data_subheader">
            <xsl:value-of select="$taskEstimated" /> #task.man_days#
          </td>
          <td class="table_data_subheader">
            <xsl:call-template name="percentage">
              <xsl:with-param name="max" select="100"/>
              <xsl:with-param name="value" select="$taskProgress"/>
            </xsl:call-template>
          </td>
        </tr>
      </xsl:for-each>
    </table>
  </xsl:template>


  <xsl:template name="generateFolderSubSummaryWithoutProgress">
    <xsl:param name="parentName"/>

    <table width="100%">
      <tr>
        <td class="table_data_header">#task.Tasks#</td>
        <td class="table_data_header">#task.Priority#</td>
        <td class="table_data_header">#task.Estimated#</td>
      </tr>
      <xsl:for-each select="task">
        <xsl:variable name="taskId"        select="@id" />
        <xsl:variable name="taskName"      select="@name" />
        <xsl:variable name="taskPriority"  select="@priority" />
        <xsl:variable name="taskEstimated" select="@estimated" />

        <!-- Tasks -->
        <tr>
          <td class="table_data_subheader">
            <!-- anchor link -->
            <a>
              <xsl:attribute name="href">
                <xsl:call-template name="generateSharpUniqueId">
                  <xsl:with-param name="type" select="'task'"/>
                  <xsl:with-param name="id" select="@id"/>
                </xsl:call-template>
              </xsl:attribute>
              [TA_<xsl:value-of select="$taskId" />] <xsl:value-of select="$taskName" />
            </a>
          </td>
          <td class="table_data_subheader">
            <xsl:value-of select="$taskPriority" />
          </td>
          <td class="table_data_subheader">
            <xsl:value-of select="$taskEstimated" /> #task.man_days#
          </td>
        </tr>
      </xsl:for-each>
    </table>
  </xsl:template>






  <xsl:template name="generateDetailsFolder">
    <xsl:param name="parentName"/>
    <xsl:param name="sprintId"/>

    <xsl:variable name="folderName" select="@name" />
    <xsl:variable name="folderDescription" select="description" />

    <xsl:if test="count(task) > 0">
      <a>
        <xsl:attribute name="name">
          <xsl:call-template name="generateUniqueIdFromTwoIds">
            <xsl:with-param name="type1" select="'sprint'"/>
            <xsl:with-param name="id1"   select="$sprintId"/>
            <xsl:with-param name="type2" select="'folder'"/>
            <xsl:with-param name="id2"   select="@id"/>
          </xsl:call-template>
        </xsl:attribute>
      </a>
      
      <h3><xsl:value-of select="concat($parentName, '/', $folderName)" /></h3>
      <!-- folder description -->
      <p><xsl:value-of disable-output-escaping="yes" select="$folderDescription" /></p>

      <xsl:call-template name="generateFolderSubSummary">
        <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
        <xsl:with-param name="sprintId" select="$sprintId"/>
      </xsl:call-template>

      <xsl:call-template name="generateTasksDetails">
        <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
        <xsl:with-param name="sprintId" select="$sprintId"/>
      </xsl:call-template>
    </xsl:if>

    <!-- Recursivity -->
    <xsl:for-each select="folder">
      <xsl:if test="count(descendant::task) > 0">
        <xsl:call-template name="generateDetailsFolder">
          <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
          <xsl:with-param name="sprintId" select="$sprintId"/>
        </xsl:call-template>
      </xsl:if>
    </xsl:for-each>
  </xsl:template>

  <xsl:template name="generateDetailsFolderWithoutProgress">
    <xsl:param name="parentName"/>

    <xsl:variable name="folderName" select="@name" />

    <xsl:if test="count(task) > 0">
      <h3><xsl:value-of select="concat($parentName, '/', $folderName)" /></h3>

      <xsl:call-template name="generateFolderSubSummaryWithoutProgress">
        <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
      </xsl:call-template>

      <xsl:call-template name="generateTasksDetailsWithoutProgress">
        <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
      </xsl:call-template>
    </xsl:if>

    <!-- Recursivity -->
    <xsl:for-each select="folder">
      <xsl:if test="count(descendant::task) > 0">
        <xsl:call-template name="generateDetailsFolderWithoutProgress">
          <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
        </xsl:call-template>
      </xsl:if>
    </xsl:for-each>
  </xsl:template>




  <xsl:template name="generateSprintDetails">
    <xsl:param name="parentName"/>

    <xsl:variable name="sprintName"      select="@name" />
    <xsl:variable name="sprintStatus"    select="@status" />
    <xsl:variable name="sprintStartDate" select="@startDate" />
    <xsl:variable name="sprintStopDate"  select="@stopDate" />

    <!-- check if there are some tasks under this sprint -->
    <xsl:variable name="nbChildTasks" select="count(descendant::task)" />
    <xsl:if test="$nbChildTasks > 0">
      <a>
        <xsl:attribute name="name">
          <xsl:call-template name="generateUniqueId">
            <xsl:with-param name="type" select="'sprint'"/>
            <xsl:with-param name="id" select="@id"/>
          </xsl:call-template>
        </xsl:attribute>
      </a>
      <h2>
        <img src="#images#/IconSprint.gif"/>&#160;
        <xsl:value-of disable-output-escaping="yes" select="$sprintName" />&#160;
        (<xsl:call-template name="statusToString"><xsl:with-param name="status" select="$sprintStatus"/></xsl:call-template>)
      </h2>

      <br/>
      <table>
        <tr><td class="table_label" align="right"><b>#task.Start_Date#:</b>&#160;</td><td class="table_value" align="left"><xsl:value-of disable-output-escaping="yes" select="$sprintStartDate" /></td></tr>
        <tr><td class="table_label" align="right"><b>#task.Stop_Date#:</b>&#160;</td><td class="table_value" align="left"><xsl:value-of disable-output-escaping="yes" select="$sprintStopDate" /></td></tr>
      </table>

      <!-- ******************* RESOURCES *************************** -->
      <table>
        <tr>
          <td class="table_data_header">#task.Resources#</td>
          <td class="table_data_header">#task.Availability#</td>
        </tr>
        <br/>
        <xsl:for-each select="users/user">
          <xsl:variable name="availability" select="@availability" />
          <tr>
            <td class="table_data_content"><b><xsl:value-of select="@name" />&#160;&#160;&#160;&#160;&#160;</b></td>
            <td class="table_data_content"><xsl:value-of select="concat($availability, ' %')" /></td>
          </tr>
        </xsl:for-each>
      </table>

      <br/>

      <!-- ***************** TASKS PER PRIORITY ******************** -->
      <table width="100%">
        <tr>
          <td class="table_data_header">#task.Per_priority#</td>
          <td class="table_data_header">#task.Priority#</td>
          <td class="table_data_header">#task.Estimated#</td>
          <td class="table_data_header" width="1%">#task.Progress#</td>
        </tr>
        <xsl:for-each select="descendant::task">
          <xsl:sort select="@priority" data-type="number"/>

          <xsl:variable name="taskId"        select="@id" />
          <xsl:variable name="taskName"      select="@name" />
          <xsl:variable name="taskPriority"  select="@priority" />
          <xsl:variable name="taskEstimated" select="@estimated" />
          <xsl:variable name="taskProgress"  select="@progress" />

          <!-- Tasks -->
          <tr>
            <td class="table_data_subheader">
              <!-- anchor link -->
              <a>
                <xsl:attribute name="href">
                  <xsl:call-template name="generateSharpUniqueId">
                    <xsl:with-param name="type" select="'task'"/>
                    <xsl:with-param name="id" select="@id"/>
                  </xsl:call-template>
                </xsl:attribute>
                [TA_<xsl:value-of select="$taskId" />] <xsl:value-of select="$taskName" />
              </a>
            </td>
            <td class="table_data_subheader">
              <xsl:value-of select="$taskPriority" />
            </td>
            <td class="table_data_subheader">
              <xsl:value-of select="$taskEstimated" /> #task.man_days#
            </td>
            <td class="table_data_subheader">
              <xsl:call-template name="percentage">
                <xsl:with-param name="max" select="100"/>
                <xsl:with-param name="value" select="$taskProgress"/>
              </xsl:call-template>
            </td>
          </tr>
        </xsl:for-each>
      </table>

    </xsl:if>
    <xsl:if test="$nbChildTasks = 0">
      <a>
        <xsl:attribute name="name">
          <xsl:call-template name="generateUniqueId">
            <xsl:with-param name="type" select="'sprint'"/>
            <xsl:with-param name="id" select="@id"/>
          </xsl:call-template>
        </xsl:attribute>
      </a>
      <h3><xsl:value-of select="concat($parentName, '/', $sprintName)" /></h3>
      #task.No_task_available#
    </xsl:if>
  </xsl:template>



  <xsl:template name="generateTasksDetails">
    <xsl:param name="parentName"/>
    <xsl:param name="sprintId"/>

    <xsl:for-each select="task">
      <xsl:variable name="taskId"          select="@id" />
      <xsl:variable name="taskName"        select="@name" />
      <xsl:variable name="taskPriority"    select="@priority" />
      <xsl:variable name="taskEstimated"   select="@estimated" />
      <xsl:variable name="taskProgress"    select="@progress" />
      <xsl:variable name="taskDescription" select="description" />

      <br/>
      <a>
        <xsl:attribute name="name">
          <xsl:call-template name="generateUniqueIdFromTwoIds">
            <xsl:with-param name="type1" select="'sprint'"/>
            <xsl:with-param name="id1"   select="$sprintId"/>
            <xsl:with-param name="type2" select="'task'"/>
            <xsl:with-param name="id2"   select="@id"/>
          </xsl:call-template>
        </xsl:attribute>
      </a>

      <table width="100%">
        <tr><td colspan="3" class="table_data_subheader">[TA_<xsl:value-of select="$taskId"/>]&#160;<xsl:value-of select="$taskName" /></td></tr>
        <tr>
          <td width="33%" class="table_data_subsubheader">#task.Priority#</td>
          <td width="33%" class="table_data_subsubheader">#task.Estimated#</td>
          <td width="33%" class="table_data_subsubheader">#task.Progress#</td>
        </tr>
        <tr>
          <td class="table_data_content"><xsl:value-of select="$taskPriority" /></td>
          <td class="table_data_content"><xsl:value-of select="$taskEstimated" /> #task.man_days#</td>
          <td class="table_data_content"><xsl:value-of select="$taskProgress" /> %</td>
        </tr>
        <tr><td colspan="3" class="table_data_subsubheader">#task.Description#</td></tr>
        <tr>
          <td colspan="3" class="table_data_content">
            <xsl:value-of disable-output-escaping="yes" select="$taskDescription" />
            &#160; <!-- to avoid having a ugly effect when there is no description -->
          </td>
        </tr>
      </table>
      <br/>
    </xsl:for-each>
  </xsl:template>

  <xsl:template name="generateTasksDetailsWithoutProgress">
    <xsl:param name="parentName"/>

    <xsl:for-each select="task">
      <xsl:variable name="taskId"          select="@id" />
      <xsl:variable name="taskName"        select="@name" />
      <xsl:variable name="taskPriority"    select="@priority" />
      <xsl:variable name="taskEstimated"   select="@estimated" />
      <xsl:variable name="taskDescription" select="description" />

      <br/>
      <a>
        <xsl:attribute name="name">
          <xsl:call-template name="generateUniqueId">
            <xsl:with-param name="type" select="'task'"/>
            <xsl:with-param name="id" select="@id"/>
          </xsl:call-template>
        </xsl:attribute>
      </a>

      <table width="100%">
        <tr><td colspan="2" class="table_data_subheader">[TA_<xsl:value-of select="$taskId"/>]&#160;<xsl:value-of select="$taskName" /></td></tr>
        <tr>
          <td width="33%" class="table_data_subsubheader">#task.Priority#</td>
          <td width="33%" class="table_data_subsubheader">#task.Estimated#</td>
        </tr>
        <tr>
          <td class="table_data_content"><xsl:value-of select="$taskPriority" /></td>
          <td class="table_data_content"><xsl:value-of select="$taskEstimated" /> #task.man_days#</td>
        </tr>
        <tr><td colspan="3" class="table_data_subsubheader">#task.Description#</td></tr>
        <tr>
          <td colspan="3" class="table_data_content">
            <xsl:value-of disable-output-escaping="yes" select="$taskDescription" />
            &#160; <!-- to avoid having a ugly effect when there is no description -->
          </td>
        </tr>
      </table>
      <br/>
    </xsl:for-each>
  </xsl:template>







  <!-- METRICS -->

  <xsl:template name="generateGlobalMetrics">
    <xsl:variable name="nbGlobalProjects" select="count(tasks/descendant::project)"/>
    <xsl:variable name="nbGlobalSprints"  select="count(tasks/descendant::sprint)"/>
    <xsl:variable name="nbGlobalTasks"    select="count(tasks/descendant::task)"/>

    <xsl:if test="$nbGlobalProjects != 0">
      <table>
        <tr>
          <td class="table_label">#task.Nb_projects#:</td>
          <td class="table_value" width="8px">&#160;</td>
          <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobalProjects"/></td>
        </tr>
        <xsl:if test="$nbGlobalSprints != 0">
            <tr>
              <td class="table_label">#task.Nb_sprints#:</td>
              <td class="table_value" width="8px">&#160;</td>
              <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobalSprints"/></td>
            </tr>
            <xsl:if test="$nbGlobalTasks != 0">
                <tr>
                  <td class="table_label">#task.Nb_tasks#:</td>
                  <td class="table_value" width="8px">&#160;</td>
                  <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobalTasks"/></td>
                </tr>
            </xsl:if>
            <xsl:if test="$nbGlobalTasks = 0">
              <h3>#task.No_task_available#</h3>
            </xsl:if>
        </xsl:if>
        <xsl:if test="$nbGlobalSprints = 0">
          <h3>#task.No_sprint_available#</h3>
        </xsl:if>
      </table>
    </xsl:if>
    <xsl:if test="$nbGlobalProjects = 0">
      <h3>#task.No_project_available#</h3>
    </xsl:if>
  </xsl:template>

  <xsl:template name="generateFolderDetails">
    <xsl:variable name="nbTasks"   select="count(descendant-or-self::task)"/>

    <xsl:if test="$nbTasks != 0">
      <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="$nbTasks"/></td>
    </xsl:if>
    <xsl:if test="$nbTasks = 0">
      <td class="table_data_content"></td>
    </xsl:if>
  </xsl:template>

</xsl:stylesheet>