<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="html" indent="yes" encoding="UTF-8"/>

  <!-- global variables -->
  <xsl:variable name="codebase" select="testplans/@codebase" />
  <xsl:variable name="bugtrackingType" select="testplans/@bugTrackingType" />
  <xsl:variable name="requirementTrackingType" select="testplans/@requirementTrackingType" />
  <xsl:variable name="specificationInLifecycle" select="testplans/@specificationInLifecycle" />

  <xsl:include href="#export_absolute_path#xsl/lib.xslt"/>
  <xsl:include href="#export_absolute_path#xsl/testplanHTML_lib.xslt"/>
  <xsl:template match="/">

    <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">

	  <head>		
		<title>XStudio Report</title>
		<meta name="description" content="XStudio"/>
		<meta name="keywords" content="xstudio, report"/>
		<meta name="author" lang="en" content="XQual"/>
		<meta name="robots" content="noarchive"/>
		<meta http-equiv="Pragma" content="no-cache"/>
	    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
		<meta http-equiv="Content-Language" content="en"/>		
		<link rel="stylesheet" href="#css#" type="text/css"/>		
	  </head>

      <body>
        <xsl:variable name="nbCategory" select="count(testplans/category)" />

        <div align="center">
          <table width="100%">
            <tr>
              <td valign="top"><img src="#images#/#company_logo#"/></td>
            </tr>
          </table>
          <br/>

          <xsl:if test="$nbCategory > 1">
            <xsl:if test="count(testplans/campaign) = 1">
               <span class="report_title">#testplan.Campaign_Testplan#</span><br/>
            </xsl:if>
            <xsl:if test="count(testplans/campaign) = 0">
              <span class="report_title">#testplan.Complete_Testplan#</span><br/>
            </xsl:if>
          </xsl:if>
          <xsl:if test="$nbCategory = 1">
            <span class="report_title">#testplan.Category_Testplan#</span><br/>
          </xsl:if>
          <xsl:if test="$nbCategory = 0">
            <span class="report_title">#testplan.Folder_Testplan#</span><br/>
          </xsl:if>

          <span class="report_title"><i>Raw Results</i></span><br/>

          <xsl:call-template name="big_hr"/>
          <a class="report_table_of_content" href="#_metrics">#testplan.Metrics#</a><br/>
          <a class="report_table_of_content" href="#_summary">#testplan.Summary#</a><br/>
          <a class="report_table_of_content" href="#_details">#testplan.Details#</a><br/>
          <xsl:call-template name="big_hr"/>
        </div>

        <a name="_metrics"/>
        <h1>#testplan.Metrics#</h1>
        <xsl:call-template name="generateGlobalMetrics"/>


        <a name="_details"/>
        <h1>#testplan.Details#</h1>
        <!-- ******************* TESTPLAN DETAILS *************************** -->
        <xsl:if test="$nbCategory > 0">
          <xsl:for-each select="testplans/category[count(descendant-or-self::test)>0]">
            <xsl:variable name="categoryName" select="@name" />

            <!-- Categories -->
            <a>
              <xsl:attribute name="name">
                <xsl:call-template name="generateUniqueId">
                  <xsl:with-param name="type" select="'category'"/>
                  <xsl:with-param name="id" select="@id"/>
                </xsl:call-template>
              </xsl:attribute>
            </a>
            <h2>
              <img src="#images#/IconCategory.gif"/>&#160;
              <xsl:value-of disable-output-escaping="yes" select="$categoryName" />&#160;
            </h2>

            <!-- Attachments -->
            <xsl:call-template name="generateAttachments">
              <xsl:with-param name="parentType"     select="'CT_'"/>
              <xsl:with-param name="attachmentIcon" select="'#images#/IconAttachment.gif'"/>
            </xsl:call-template>

            <!-- Tests -->
            <xsl:for-each select="folder[count(descendant::test) > 0]"> <!-- recursive call to display folders -->
                <xsl:call-template name="generateDetailsFolder">
                  <xsl:with-param name="parentName" select="$categoryName"/>
                </xsl:call-template>
            </xsl:for-each>

          </xsl:for-each>
        </xsl:if>
        <xsl:if test="$nbCategory = 0">
          <!-- Folders -->
          <xsl:for-each select="testplans/folder[count(descendant::test) > 0]"> <!-- recursive call to display folders -->
              <xsl:call-template name="generateDetailsFolder">
                <xsl:with-param name="parentName" select="''"/>
              </xsl:call-template>
          </xsl:for-each>
        </xsl:if>

      </body>
    </html>

  </xsl:template>









  <xsl:template name="generateSummaryFolder">
    <xsl:param name="parentName"/>
    <xsl:param name="tab"/>

    <xsl:variable name="folderName" select="@name" />

    <tr>
      <td class="table_data_content">
        <!-- anchor link -->
        <xsl:value-of disable-output-escaping="yes" select="$tab" />
        <a>
        <xsl:attribute name="href">
          <xsl:call-template name="generateSharpUniqueId">
            <xsl:with-param name="type" select="'folder'"/>
            <xsl:with-param name="id" select="@id"/>
          </xsl:call-template>
        </xsl:attribute>
        <xsl:value-of select="$folderName" />
        </a>
      </td>
      <xsl:call-template name="generateNbTd">
        <xsl:with-param name="nodeSet" select="descendant-or-self::test"/>
        <xsl:with-param name="tdStyle" select="'table_data_content'"/>
      </xsl:call-template>
      <xsl:call-template name="generateNbTd">
        <xsl:with-param name="nodeSet" select="descendant-or-self::testcase"/>
        <xsl:with-param name="tdStyle" select="'table_data_content'"/>
      </xsl:call-template>
      <xsl:call-template name="generateCompletionTd">
        <xsl:with-param name="nodeSet" select="descendant-or-self::testcase"/>
        <xsl:with-param name="tdStyle" select="'table_data_content'"/>
      </xsl:call-template>
    </tr>

    <xsl:for-each select="folder">
      <xsl:call-template name="generateSummaryFolder">
        <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
        <xsl:with-param name="tab" select="concat($tab, '&#160;&#160;&#160;&#160;')"/>
      </xsl:call-template>
    </xsl:for-each>
  </xsl:template>


  <xsl:template name="generateFolderSubSummary">
    <xsl:param name="parentName"/>

    <table width="100%">
      <tr>
        <td class="table_data_header">#testplan.Tests#</td>
        <td class="table_data_header">#testplan.Nb_testcases#</td>
        <td class="table_data_header">#testplan.Implemented#</td>
      </tr>
      <xsl:for-each select="test">
        <xsl:variable name="testId" select="@id" />
        <xsl:variable name="testName" select="@name" />
        <xsl:variable name="testNbTestcases" select="count(testcase)" />
        <xsl:variable name="testNbTestcasesImplemented" select="count(testcase[@devCompleted='1'])" />

        <!-- Tests -->
        <tr>
          <td class="table_data_subheader">
            <!-- anchor link -->
            <a>
              <xsl:attribute name="href">
                <xsl:call-template name="generateSharpUniqueId">
                  <xsl:with-param name="type" select="'test'"/>
                  <xsl:with-param name="id" select="@id"/>
                </xsl:call-template>
              </xsl:attribute>
              [T_<xsl:value-of select="$testId" />]&#160;<xsl:value-of select="$testName" />
            </a>
          </td>
          <td class="table_data_subheader">
            <xsl:value-of select="$testNbTestcases" />
          </td>
          <td class="table_data_subheader">
            <xsl:value-of select="$testNbTestcasesImplemented" />
          </td>
        </tr>
      </xsl:for-each>
    </table>
  </xsl:template>



  <xsl:template name="generateDetailsFolder">
    <xsl:param name="parentName"/>

    <xsl:variable name="folderName" select="@name" />
    <xsl:variable name="folderDescription" select="description" />

    <xsl:if test="count(test) > 0">
      <a>
        <xsl:attribute name="name">
          <xsl:call-template name="generateUniqueId">
            <xsl:with-param name="type" select="'folder'"/>
            <xsl:with-param name="id" select="@id"/>
          </xsl:call-template>
        </xsl:attribute>
      </a>
      
      <h3><xsl:value-of select="concat($parentName, '/', $folderName)" /></h3>
      <!-- folder description -->
      <p><xsl:value-of disable-output-escaping="yes" select="$folderDescription" /></p>

      <xsl:call-template name="generateAttachments">
        <xsl:with-param name="parentType" select="'FL_'"/>
        <xsl:with-param name="attachmentIcon" select="'#images#/IconAttachment.gif'"/>
      </xsl:call-template>

      <xsl:call-template name="generateFolderSubSummary">
        <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
      </xsl:call-template>

      <xsl:call-template name="generateTestsDetailsFromCurrentLevel"/>
    </xsl:if>

    <!-- Recursivity -->
    <xsl:for-each select="folder">
      <xsl:if test="count(descendant::test) > 0">
        <xsl:call-template name="generateDetailsFolder">
          <xsl:with-param name="parentName" select="concat($parentName, '/', $folderName)"/>
        </xsl:call-template>
      </xsl:if>
    </xsl:for-each>
  </xsl:template>

  <xsl:template name="generateGlobalMetrics">
    <xsl:variable name="nbGlobalTests"            select="count(testplans/descendant::test)"/>
    <xsl:variable name="nbGlobalTestcases"        select="count(testplans/descendant::testcase)"/>
    <xsl:variable name="nbGlobalTestcasesNotImpl" select="count(testplans/descendant::testcase[@devCompleted='0'])"/>
    <xsl:variable name="nbGlobalTestcasesImpl"    select="count(testplans/descendant::testcase[@devCompleted='1'])"/>
    <xsl:variable name="globalCompletion"         select="format-number(100 * $nbGlobalTestcasesImpl div $nbGlobalTestcases, '##.##')"/>

    <xsl:if test="$nbGlobalTestcases != 0">
      <table>
        <tr>
          <td class="table_label">#testplan.Nb_tests#:</td>
          <td class="table_value" width="8px">&#160;</td>
          <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobalTests"/></td>
        </tr>
        <tr>
          <td class="table_label">#testplan.Nb_testcases#:</td>
          <td class="table_value" width="8px">&#160;</td>
          <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobalTestcases"/></td>
        </tr>
        <tr>
          <td class="table_label">#testplan.Not_implemented#:</td>
          <td class="table_value" width="8px">&#160;</td>
          <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobalTestcasesNotImpl"/></td>
        </tr>
        <tr>
          <td class="table_label">#testplan.Implemented#:</td>
          <td class="table_value" width="8px">&#160;</td>
          <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="$nbGlobalTestcasesImpl"/></td>
        </tr>
        <tr>
          <td class="table_label">#testplan.Completion#:</td>
          <td class="table_value" width="8px">&#160;</td>
          <td class="table_value"><xsl:value-of disable-output-escaping="yes" select="concat($globalCompletion, ' %')"/></td>
        </tr>
      </table>
    </xsl:if>
    <xsl:if test="$nbGlobalTestcases = 0">
      <h3>no tests available</h3>
    </xsl:if>
  </xsl:template>


  <xsl:template name="generateCategoryMetrics">
    <xsl:variable name="nbTests"            select="count(descendant::test)"/>
    <xsl:variable name="nbTestcases"        select="count(descendant::testcase)"/>
    <xsl:variable name="nbTestcasesNotImpl" select="count(descendant::testcase[@devCompleted='0'])"/>
    <xsl:variable name="nbTestcasesImpl"    select="count(descendant::testcase[@devCompleted='1'])"/>
    <xsl:variable name="completion"         select="format-number(100 * $nbTestcasesImpl div $nbTestcases, '##.##')"/>

    <xsl:if test="$nbTests != 0">
      <td class="table_data_subheader"><xsl:value-of disable-output-escaping="yes" select="$nbTests"/></td>
    </xsl:if>
    <xsl:if test="$nbTests = 0">
      <td class="table_data_subheader"></td>
    </xsl:if>

    <xsl:if test="$nbTestcases != 0">
      <td class="table_data_subheader"><xsl:value-of disable-output-escaping="yes" select="$nbTestcases"/></td>
      <td class="table_data_subheader"><xsl:value-of disable-output-escaping="yes" select="$nbTestcasesNotImpl"/></td>
      <td class="table_data_subheader"><xsl:value-of disable-output-escaping="yes" select="$nbTestcasesImpl"/></td>
      <td class="table_data_subheader"><xsl:value-of disable-output-escaping="yes" select="concat($completion, ' %')"/></td>
    </xsl:if>
    <xsl:if test="$nbTestcases = 0">
      <td class="table_data_subheader"></td>
      <td class="table_data_subheader"></td>
      <td class="table_data_subheader"></td>
      <td class="table_data_subheader"></td>
    </xsl:if>
  </xsl:template>


  <xsl:template name="generateFolderMetrics">
    <xsl:variable name="nbTests"            select="count(descendant-or-self::test)"/>
    <xsl:variable name="nbTestcases"        select="count(descendant-or-self::testcase)"/>
    <xsl:variable name="nbTestcasesNotImpl" select="count(descendant-or-self::testcase[@devCompleted='0'])"/>
    <xsl:variable name="nbTestcasesImpl"    select="count(descendant-or-self::testcase[@devCompleted='1'])"/>
    <xsl:variable name="completion"         select="format-number(100 * $nbTestcasesImpl div $nbTestcases, '##.##')"/>

    <xsl:if test="$nbTests != 0">
      <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="$nbTests"/></td>
    </xsl:if>
    <xsl:if test="$nbTests = 0">
      <td class="table_data_content"></td>
    </xsl:if>

    <xsl:if test="$nbTestcases != 0">
      <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="$nbTestcases"/></td>
      <xsl:if test="$nbTestcasesNotImpl != 0">
        <td class="table_data_content_red"><xsl:value-of disable-output-escaping="yes" select="$nbTestcasesNotImpl"/></td>
      </xsl:if>
      <xsl:if test="$nbTestcasesNotImpl = 0">
        <td class="table_data_content_red">&#160;</td>
      </xsl:if>
      <xsl:if test="$nbTestcasesImpl != 0">
        <td class="table_data_content_green"><xsl:value-of disable-output-escaping="yes" select="$nbTestcasesImpl"/></td>
      </xsl:if>
      <xsl:if test="$nbTestcasesImpl = 0">
        <td class="table_data_content_green">&#160;</td>
      </xsl:if>
      <xsl:if test="$completion != 0">
        <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="concat($completion, ' %')"/></td>
      </xsl:if>
      <xsl:if test="$completion = 0">
        <td class="table_data_content">&#160;</td>
      </xsl:if>
    </xsl:if>
    <xsl:if test="$nbTestcases = 0">
      <td class="table_data_content">&#160;</td>
      <td class="table_data_content">&#160;</td>
      <td class="table_data_content">&#160;</td>
      <td class="table_data_content">&#160;</td>
    </xsl:if>
  </xsl:template>

  <xsl:template name="generateFolderDetails">
    <xsl:variable name="nbTests"            select="count(descendant-or-self::test)"/>
    <xsl:variable name="nbTestcases"        select="count(descendant-or-self::testcase)"/>
    <xsl:variable name="nbTestcasesNotImpl" select="count(descendant-or-self::testcase[@devCompleted='0'])"/>
    <xsl:variable name="nbTestcasesImpl"    select="count(descendant-or-self::testcase[@devCompleted='1'])"/>
    <xsl:variable name="completion"         select="format-number(100 * $nbTestcasesImpl div $nbTestcases, '##.##')"/>

    <xsl:if test="$nbTests != 0">
      <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="$nbTests"/></td>
    </xsl:if>
    <xsl:if test="$nbTests = 0">
      <td class="table_data_content"></td>
    </xsl:if>

    <xsl:if test="$nbTestcases != 0">
      <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="$nbTestcases"/></td>
      <xsl:if test="$nbTestcasesNotImpl != 0">
        <td class="table_data_content_red"><xsl:value-of disable-output-escaping="yes" select="$nbTestcasesNotImpl"/></td>
      </xsl:if>
      <xsl:if test="$nbTestcasesNotImpl = 0">
        <td class="table_data_content_red">&#160;</td>
      </xsl:if>
      <xsl:if test="$nbTestcasesImpl != 0">
        <td class="table_data_content_green"><xsl:value-of disable-output-escaping="yes" select="$nbTestcasesImpl"/></td>
      </xsl:if>
      <xsl:if test="$nbTestcasesImpl = 0">
        <td class="table_data_content_green">&#160;</td>
      </xsl:if>
      <xsl:if test="$completion != 0">
        <td class="table_data_content"><xsl:value-of disable-output-escaping="yes" select="concat($completion, ' %')"/></td>
      </xsl:if>
      <xsl:if test="$completion = 0">
        <td class="table_data_content">&#160;</td>
      </xsl:if>
    </xsl:if>
    <xsl:if test="$nbTestcases = 0">
      <td class="table_data_content">&#160;</td>
      <td class="table_data_content">&#160;</td>
      <td class="table_data_content">&#160;</td>
      <td class="table_data_content">&#160;</td>
    </xsl:if>
  </xsl:template>

</xsl:stylesheet>